@@ -21,8 +21,6 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
-from six import string_types
-
 from distutils.version import StrictVersion
 
 import hpccm.config
@@ -97,7 +95,7 @@ class kokkos(bb_base, hpccm.templates.downloader, hpccm.templates.envvars):
     specified by `version`.
 
     version: The version of Kokkos source to download.  The default
-    value is `3.1.01`.
+    value is `3.2.00`.
 
     # Examples
 
@@ -124,7 +122,7 @@ class kokkos(bb_base, hpccm.templates.downloader, hpccm.templates.envvars):
         self.__ospackages = kwargs.pop('ospackages', [])
         self.__powertools = False # enable the CentOS PowerTools repo
         self.__prefix = kwargs.pop('prefix', '/usr/local/kokkos')
-        self.__version = kwargs.pop('version', '3.1.01')
+        self.__version = kwargs.pop('version', '3.2.00')
 
         if self.repository:
             self.__directory = ''
@@ -229,7 +227,6 @@ class kokkos(bb_base, hpccm.templates.downloader, hpccm.templates.envvars):
         Stage1 += k.runtime()
         ```
         """
-        instructions = []
-        instructions.append(comment('Kokkos'))
-        instructions.append(self.__bb.runtime(_from=_from))
-        return '\n'.join(str(x) for x in instructions)
+        self.rt += comment('Kokkos')
+        self.rt += self.__bb.runtime(_from=_from)
+        return str(self.rt)
