@@ -92,7 +92,7 @@ class llvm(bb_base, hpccm.templates.envvars):
         super(llvm, self).__init__(**kwargs)
 
         # Current LLVM trunk version
-        self.__trunk_version = '13'
+        self.__trunk_version = '15'
 
         self.__apt_keys = []       # Filled in below
         self.__apt_repositories = [] # Filled in below
@@ -158,8 +158,8 @@ class llvm(bb_base, hpccm.templates.envvars):
 
                 if self.__upstream:
                     # Upstream packages from apt.llvm.org
-                    if hpccm.config.g_cpu_arch != cpu_arch.X86_64:
-                        raise RuntimeError('LLVM upstream builds only available for x86')
+                    if hpccm.config.g_cpu_arch == cpu_arch.PPC64LE:
+                        raise RuntimeError('LLVM upstream builds are not available for ppc64le')
 
                     self.__apt_keys = ['https://apt.llvm.org/llvm-snapshot.gpg.key']
                     self.__apt_repositories = self.__upstream_package_repos()
@@ -338,12 +338,19 @@ class llvm(bb_base, hpccm.templates.envvars):
         """Return the package repositories for the given distro and llvm
         version.  The development branch repositories are not
         versioned and must be handled differently.  Currently the
-        development branch is version 12."""
+        development branch is version 14."""
 
         codename = 'xenial'
         codename_ver = 'xenial'
 
-        if (hpccm.config.g_linux_version >= StrictVersion('20.0') and
+        if (hpccm.config.g_linux_version >= StrictVersion('22.0') and
+            hpccm.config.g_linux_version < StrictVersion('23.0')):
+            codename = 'jammy'
+            if self.__version == self.__trunk_version:
+                codename_ver = 'jammy'
+            else:
+                codename_ver = 'jammy-{}'.format(self.__version)
+        elif (hpccm.config.g_linux_version >= StrictVersion('20.0') and
             hpccm.config.g_linux_version < StrictVersion('21.0')):
             codename = 'focal'
             if self.__version == self.__trunk_version:
