@@ -50,11 +50,11 @@ class baseimage(object):
 
     _distro: The underlying Linux distribution of the base image.
     Valid values are `centos`, `centos7`, `centos8`, `redhat`, `rhel`,
-    `rhel7`, `rhel8, `rockylinux8`, `ubuntu`, `ubuntu16`, `ubuntu18`,
-    and `ubuntu20`.  By default, the primitive attempts to figure out
-    the Linux distribution by inspecting the image identifier, and
-    falls back to `ubuntu` if unable to determine the Linux
-    distribution automatically.
+    `rhel7`, `rhel8`, `rockylinux8`, `ubuntu`, `ubuntu16`, `ubuntu18`,
+    `ubuntu20`, and `ubuntu22`.  By default, the primitive attempts to
+    figure out the Linux distribution by inspecting the image
+    identifier, and falls back to `ubuntu` if unable to determine the
+    Linux distribution automatically.
 
     _docker_env: Boolean specifying whether to load the Docker base
      image environment, i.e., source
@@ -116,6 +116,8 @@ class baseimage(object):
             hpccm.config.set_linux_distro('ubuntu18')
         elif self.__distro == 'ubuntu20':
             hpccm.config.set_linux_distro('ubuntu20')
+        elif self.__distro == 'ubuntu22':
+            hpccm.config.set_linux_distro('ubuntu22')
         elif self.__distro == 'centos':
             hpccm.config.set_linux_distro('centos')
         elif self.__distro == 'centos7':
@@ -148,6 +150,8 @@ class baseimage(object):
             hpccm.config.set_linux_distro('ubuntu18')
         elif re.search(r'ubuntu:?20', self.image):
             hpccm.config.set_linux_distro('ubuntu20')
+        elif re.search(r'ubuntu:?22', self.image):
+            hpccm.config.set_linux_distro('ubuntu22')
         elif re.search(r'ubuntu', self.image):
             hpccm.config.set_linux_distro('ubuntu')
         else:
