@@ -3,7 +3,7 @@ MILC 7.8.1
 
 Contents:
   Ubuntu 16.04
-  CUDA version 10.1
+  CUDA version 11.2
   GNU compilers (upstream)
   OFED (upstream)
   OpenMPI version 3.1.4
@@ -20,7 +20,7 @@ Stage0 += comment(__doc__.strip(), reformat=False)
 ###############################################################################
 # Devel stage
 ###############################################################################
-Stage0 += baseimage(image='nvcr.io/nvidia/cuda:10.1-devel-ubuntu18.04',
+Stage0 += baseimage(image='nvcr.io/nvidia/cuda:11.2.0-devel-ubuntu18.04',
                     _as='devel')
 
 Stage0 += gnu()
@@ -46,6 +46,7 @@ Stage0 += generic_cmake(branch='develop',
                                     '-D QUDA_LINK_HISQ=ON',
                                     '-D QUDA_MPI=ON'],
                         install=False,
+                        ldconfig=True,
                         postinstall=['cp -a /var/tmp/quda/build/* /usr/local/quda'],
                         preconfigure=['mkdir -p /usr/local/quda'],
                         prefix='/usr/local/quda',
@@ -78,8 +79,10 @@ Stage0 += environment(variables={'PATH': '/usr/local/milc/bin:$PATH'})
 ###############################################################################
 # Release stage
 ###############################################################################
-Stage1 += baseimage(image='nvcr.io/nvidia/cuda:10.1-base-ubuntu18.04')
+Stage1 += baseimage(image='nvcr.io/nvidia/cuda:11.2.0-base-ubuntu18.04')
 
-Stage1 += Stage0.runtime(exclude=['generic_cmake'])
+Stage1 += packages(ospackages=['libcublas-11-2'])
+
+Stage1 += Stage0.runtime()
 
 Stage1 += environment(variables={'PATH': '/usr/local/milc/bin:$PATH'})
