@@ -194,6 +194,15 @@ def ubuntu20(function):
 
     return wrapper
 
+def ubuntu22(function):
+    """Decorator to set the Linux distribution to Ubuntu 22.04"""
+    def wrapper(*args, **kwargs):
+        hpccm.config.g_linux_distro = linux_distro.UBUNTU
+        hpccm.config.g_linux_version = StrictVersion('22.04')
+        return function(*args, **kwargs)
+
+    return wrapper
+
 def x86_64(function):
     """Decorator to set the CPU architecture to x86_64"""
     def wrapper(*args, **kwargs):
