@@ -361,15 +361,15 @@ RUN wget -qO - https://apt.llvm.org/llvm-snapshot.gpg.key | apt-key add - && \
     echo "deb-src http://apt.llvm.org/bionic/ llvm-toolchain-bionic main" >> /etc/apt/sources.list.d/hpccm.list && \
     apt-get update -y && \
     DEBIAN_FRONTEND=noninteractive apt-get install -y --no-install-recommends \
-        clang-13 \
-        clang-format-13 \
-        clang-tidy-13 \
-        libomp-13-dev && \
+        clang-15 \
+        clang-format-15 \
+        clang-tidy-15 \
+        libomp-15-dev && \
     rm -rf /var/lib/apt/lists/*
-RUN update-alternatives --install /usr/bin/clang clang $(which clang-13) 30 && \
-    update-alternatives --install /usr/bin/clang++ clang++ $(which clang++-13) 30 && \
-    update-alternatives --install /usr/bin/clang-format clang-format $(which clang-format-13) 30 && \
-    update-alternatives --install /usr/bin/clang-tidy clang-tidy $(which clang-tidy-13) 30''')
+RUN update-alternatives --install /usr/bin/clang clang $(which clang-15) 30 && \
+    update-alternatives --install /usr/bin/clang++ clang++ $(which clang++-15) 30 && \
+    update-alternatives --install /usr/bin/clang-format clang-format $(which clang-format-15) 30 && \
+    update-alternatives --install /usr/bin/clang-tidy clang-tidy $(which clang-tidy-15) 30''')
 
     @x86_64
     @ubuntu20
@@ -391,23 +391,41 @@ RUN wget -qO - https://apt.llvm.org/llvm-snapshot.gpg.key | apt-key add - && \
     echo "deb-src http://apt.llvm.org/focal/ llvm-toolchain-focal main" >> /etc/apt/sources.list.d/hpccm.list && \
     apt-get update -y && \
     DEBIAN_FRONTEND=noninteractive apt-get install -y --no-install-recommends \
-        clang-13 \
-        clang-format-13 \
-        clang-tidy-13 \
-        libomp-13-dev && \
+        clang-15 \
+        clang-format-15 \
+        clang-tidy-15 \
+        libomp-15-dev && \
     rm -rf /var/lib/apt/lists/*
-RUN update-alternatives --install /usr/bin/clang clang $(which clang-13) 30 && \
-    update-alternatives --install /usr/bin/clang++ clang++ $(which clang++-13) 30 && \
-    update-alternatives --install /usr/bin/clang-format clang-format $(which clang-format-13) 30 && \
-    update-alternatives --install /usr/bin/clang-tidy clang-tidy $(which clang-tidy-13) 30''')
+RUN update-alternatives --install /usr/bin/clang clang $(which clang-15) 30 && \
+    update-alternatives --install /usr/bin/clang++ clang++ $(which clang++-15) 30 && \
+    update-alternatives --install /usr/bin/clang-format clang-format $(which clang-format-15) 30 && \
+    update-alternatives --install /usr/bin/clang-tidy clang-tidy $(which clang-tidy-15) 30''')
 
     @aarch64
     @ubuntu
     @docker
     def test_upstream_aarch64(self):
         """Upstream builds for aarch64"""
-        with self.assertRaises(RuntimeError):
-            llvm(upstream=True, version='11')
+        l = llvm(upstream=True, version='11')
+        self.assertMultiLineEqual(str(l),
+r'''# LLVM compiler
+RUN apt-get update -y && \
+    DEBIAN_FRONTEND=noninteractive apt-get install -y --no-install-recommends \
+        apt-transport-https \
+        ca-certificates \
+        gnupg \
+        wget && \
+    rm -rf /var/lib/apt/lists/*
+RUN wget -qO - https://apt.llvm.org/llvm-snapshot.gpg.key | apt-key add - && \
+    echo "deb http://apt.llvm.org/xenial/ llvm-toolchain-xenial-11 main" >> /etc/apt/sources.list.d/hpccm.list && \
+    echo "deb-src http://apt.llvm.org/xenial/ llvm-toolchain-xenial-11 main" >> /etc/apt/sources.list.d/hpccm.list && \
+    apt-get update -y && \
+    DEBIAN_FRONTEND=noninteractive apt-get install -y --no-install-recommends \
+        clang-11 \
+        libomp-11-dev && \
+    rm -rf /var/lib/apt/lists/*
+RUN update-alternatives --install /usr/bin/clang clang $(which clang-11) 30 && \
+    update-alternatives --install /usr/bin/clang++ clang++ $(which clang++-11) 30''')
 
     @x86_64
     @ubuntu
